Import of pkgsrc-2015Q3
This commit is contained in:
@@ -1,11 +1,9 @@
|
||||
# $NetBSD: Makefile,v 1.10 2015/04/17 15:53:09 adam Exp $
|
||||
# $NetBSD: Makefile,v 1.13 2015/09/06 00:11:12 mef Exp $
|
||||
|
||||
DISTNAME= uhd-release_003_007_002
|
||||
PKGNAME= uhd-3.7.2
|
||||
PKGREVISION= 2
|
||||
DISTNAME= uhd-3.9.0
|
||||
CATEGORIES= ham
|
||||
MASTER_SITES= -https://github.com/EttusResearch/uhd/archive/${DISTNAME:S/uhd-//}${EXTRACT_SUFX}
|
||||
EXTRACT_SUFX= .zip
|
||||
MASTER_SITES= ${MASTER_SITE_GITHUB:=EttusResearch/}
|
||||
GITHUB_TAG= release_003_008_005
|
||||
|
||||
MAINTAINER= pkgsrc-users@NetBSD.org
|
||||
HOMEPAGE= http://code.ettus.com/redmine/ettus/projects/uhd/wiki
|
||||
@@ -16,17 +14,23 @@ BUILD_DEPENDS+= ${PYPKGPREFIX}-cheetah-[0-9]*:../../devel/py-cheetah
|
||||
BUILD_DEPENDS+= ${PYPKGPREFIX}-docutils>=0.12:../../textproc/py-docutils
|
||||
|
||||
CMAKE_ARGS+= -DRST2HTML_EXECUTABLE=${PREFIX}/bin/rst2html-${PYVERSSUFFIX}.py
|
||||
CMAKE_ARGS+= -Wno-dev
|
||||
|
||||
USE_LANGUAGES= c c++
|
||||
USE_TOOLS= cmake pkg-config
|
||||
USE_CMAKE= yes
|
||||
# extra pax_global_header exists, and to avoid that:
|
||||
EXTRACT_USING= gtar
|
||||
#EXTRACT_ELEMENTS= uhd-${GITHUB_TAG}
|
||||
|
||||
# Please note distribution has many stuff under uhd/, but build itself
|
||||
# needs under host/ only. Those uhd/ stuff will be handled post-{patch,install}:
|
||||
WRKSRC= ${WRKDIR}/${DISTNAME}/host
|
||||
WRKSRC= ${WRKDIR}/uhd-${GITHUB_TAG}/host
|
||||
|
||||
# The files with their name uhd-xxxx, are moved down from uhd/xxxx for this process.
|
||||
REPLACE_PYTHON= \
|
||||
utils/latency/graph.py \
|
||||
utils/latency/run_tests.py \
|
||||
utils/uhd_images_downloader.py.in \
|
||||
utils/usrp2_card_burner.py \
|
||||
utils/usrp2_card_burner_gui.py \
|
||||
@@ -36,34 +40,6 @@ REPLACE_PYTHON= \
|
||||
uhd-firmware/fx2/utils/edit-gpif-b100.py \
|
||||
uhd-firmware/fx2/utils/edit-gpif.py \
|
||||
uhd-firmware/fx2/utils/generate_regs.py \
|
||||
uhd-firmware/x300/bin_to_coe.py \
|
||||
uhd-firmware/zpu/bin/bin_to_mif.py \
|
||||
uhd-firmware/zpu/bin/bin_to_ram_macro_init.py \
|
||||
uhd-firmware/zpu/bin/divisors.py \
|
||||
uhd-firmware/zpu/bin/elf_to_sbf \
|
||||
uhd-firmware/zpu/bin/serial_loader \
|
||||
uhd-firmware/zpu/bin/uart_ihex_flash_loader.py \
|
||||
uhd-firmware/zpu/bin/uart_ihex_ram_loader.py \
|
||||
uhd-fpga/usrp1/gen_makefile_extra.py \
|
||||
uhd-fpga/usrp1/sdr_lib/gen_cordic_consts.py \
|
||||
uhd-fpga/usrp1/tb/makesine.pl \
|
||||
uhd-fpga/usrp1/toplevel/mrfm/mrfm.py \
|
||||
uhd-fpga/usrp1/toplevel/mrfm/mrfm_fft.py \
|
||||
uhd-fpga/usrp2/sdr_lib/gen_cordic_consts.py \
|
||||
uhd-fpga/usrp2/top/extract_usage.py \
|
||||
uhd-fpga/usrp2/top/python/check_inout.py \
|
||||
uhd-fpga/usrp2/top/python/check_timing.py \
|
||||
uhd-fpga/usrp3/top/python/bit_to_zynq_bin.py \
|
||||
uhd-fpga/usrp3/top/python/check_inout.py \
|
||||
uhd-fpga/usrp3/top/python/check_timing.py \
|
||||
uhd-fpga/usrp3/lib/io_port2/create-lvbitx.py
|
||||
|
||||
REPLACE_PERL= uhd-fpga/usrp1/tb/makesine.pl
|
||||
|
||||
REPLACE_BASH= \
|
||||
uhd-fpga/usrp2/top/impactor.sh \
|
||||
uhd-fpga/usrp3/top/impactor.sh \
|
||||
uhd-fpga/usrp3/top/python/batch-build
|
||||
|
||||
INSTALLATION_DIRS+= share/uhd
|
||||
INSTALLATION_DIRS+= share/uhd/firmware
|
||||
@@ -85,9 +61,9 @@ PLIST_SRC= ${PKGDIR}/PLIST
|
||||
# to receive REPLACE_PYTHON conversion ( otherwise above the range )
|
||||
post-patch:
|
||||
(cd ${WRKDIR}; \
|
||||
for i in firmware fpga images ; do \
|
||||
for i in firmware images ; do \
|
||||
${MKDIR} ${WRKSRC}/uhd-$$i ;\
|
||||
${CP} -r ${WRKDIR}/${DISTNAME}/$$i/* ${WRKSRC}/uhd-$$i ;\
|
||||
${CP} -r ${WRKDIR}/uhd-${GITHUB_TAG}/$$i/* ${WRKSRC}/uhd-$$i ;\
|
||||
done)
|
||||
|
||||
# (1) move back the files to original location after REPLACE_PYTHON handled
|
||||
@@ -96,7 +72,7 @@ post-patch:
|
||||
# Converting ${CP} into ${INTALL_DATA_DIR} and ${INSTALL_DATA} as pkglint
|
||||
# flags are NOT easy, sorry for that.
|
||||
post-install:
|
||||
for i in firmware fpga images ; do \
|
||||
for i in firmware images ; do \
|
||||
${CP} -r ${WRKSRC}/uhd-$$i/* ${DESTDIR}${PREFIX}/share/uhd/$$i/;\
|
||||
${FIND} ${DESTDIR}${PREFIX}/share/uhd/$$i -type f -exec \
|
||||
${CHMOD} -x '{}' \; ;\
|
||||
|
||||
5692
ham/uhd/PLIST
5692
ham/uhd/PLIST
File diff suppressed because it is too large
Load Diff
@@ -1,4 +1,4 @@
|
||||
@comment $NetBSD: PLIST.doxygen,v 1.2 2015/01/31 00:58:06 mef Exp $
|
||||
@comment $NetBSD: PLIST.doxygen,v 1.3 2015/08/14 06:19:13 mef Exp $
|
||||
share/doc/uhd/doxygen/html/algorithm_8hpp.html
|
||||
share/doc/uhd/doxygen/html/algorithm_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/annotated.html
|
||||
@@ -90,9 +90,6 @@ share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1managed__recv__buffer.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1managed__send__buffer-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1managed__send__buffer.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1managed__send__buffer.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1nirio__zero__copy-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1nirio__zero__copy.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1nirio__zero__copy.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1udp__simple-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1udp__simple.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1transport_1_1udp__simple.png
|
||||
@@ -143,21 +140,6 @@ share/doc/uhd/doxygen/html/classuhd_1_1usrp_1_1tx__dboard__base.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrp_1_1xcvr__dboard__base-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrp_1_1xcvr__dboard__base.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrp_1_1xcvr__dboard__base.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1boost__serialization__archive__utils-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1boost__serialization__archive__utils.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__header__t-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__header__t.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__reader__t-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__reader__t.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__writer__t-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__args__writer__t.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__xport__buf__t-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1func__xport__buf__t.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1rpc__client-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1rpc__client.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1rpc__client.png
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1usrprio__rpc__client-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1usrprio__rpc_1_1usrprio__rpc__client.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1wb__iface-members.html
|
||||
share/doc/uhd/doxygen/html/classuhd_1_1wb__iface.html
|
||||
share/doc/uhd/doxygen/html/clock__config_8hpp.html
|
||||
@@ -194,7 +176,6 @@ share/doc/uhd/doxygen/html/dir_000003.html
|
||||
share/doc/uhd/doxygen/html/dir_000004.html
|
||||
share/doc/uhd/doxygen/html/dir_000005.html
|
||||
share/doc/uhd/doxygen/html/dir_000006.html
|
||||
share/doc/uhd/doxygen/html/dir_000007.html
|
||||
share/doc/uhd/doxygen/html/doc.png
|
||||
share/doc/uhd/doxygen/html/doxygen.css
|
||||
share/doc/uhd/doxygen/html/doxygen.png
|
||||
@@ -265,8 +246,6 @@ share/doc/uhd/doxygen/html/gps__ctrl_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/hierarchy.html
|
||||
share/doc/uhd/doxygen/html/if__addrs_8hpp.html
|
||||
share/doc/uhd/doxygen/html/if__addrs_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/images_8hpp.html
|
||||
share/doc/uhd/doxygen/html/images_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/index.html
|
||||
share/doc/uhd/doxygen/html/io__type_8hpp.html
|
||||
share/doc/uhd/doxygen/html/io__type_8hpp_source.html
|
||||
@@ -300,12 +279,9 @@ share/doc/uhd/doxygen/html/namespaceuhd_1_1msg.html
|
||||
share/doc/uhd/doxygen/html/namespaceuhd_1_1transport.html
|
||||
share/doc/uhd/doxygen/html/namespaceuhd_1_1transport_1_1vrt.html
|
||||
share/doc/uhd/doxygen/html/namespaceuhd_1_1usrp.html
|
||||
share/doc/uhd/doxygen/html/namespaceuhd_1_1usrprio__rpc.html
|
||||
share/doc/uhd/doxygen/html/nav_f.png
|
||||
share/doc/uhd/doxygen/html/nav_g.png
|
||||
share/doc/uhd/doxygen/html/nav_h.png
|
||||
share/doc/uhd/doxygen/html/nirio__zero__copy_8hpp.html
|
||||
share/doc/uhd/doxygen/html/nirio__zero__copy_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/open.png
|
||||
share/doc/uhd/doxygen/html/otw__type_8hpp.html
|
||||
share/doc/uhd/doxygen/html/otw__type_8hpp_source.html
|
||||
@@ -321,10 +297,6 @@ share/doc/uhd/doxygen/html/ranges_8hpp.html
|
||||
share/doc/uhd/doxygen/html/ranges_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/ref__vector_8hpp.html
|
||||
share/doc/uhd/doxygen/html/ref__vector_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/rpc__client_8hpp.html
|
||||
share/doc/uhd/doxygen/html/rpc__client_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/rpc__common_8hpp.html
|
||||
share/doc/uhd/doxygen/html/rpc__common_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/safe__call_8hpp.html
|
||||
share/doc/uhd/doxygen/html/safe__call_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/safe__main_8hpp.html
|
||||
@@ -397,8 +369,6 @@ share/doc/uhd/doxygen/html/search/classes_15.html
|
||||
share/doc/uhd/doxygen/html/search/classes_15.js
|
||||
share/doc/uhd/doxygen/html/search/classes_16.html
|
||||
share/doc/uhd/doxygen/html/search/classes_16.js
|
||||
share/doc/uhd/doxygen/html/search/classes_17.html
|
||||
share/doc/uhd/doxygen/html/search/classes_17.js
|
||||
share/doc/uhd/doxygen/html/search/classes_2.html
|
||||
share/doc/uhd/doxygen/html/search/classes_2.js
|
||||
share/doc/uhd/doxygen/html/search/classes_3.html
|
||||
@@ -612,8 +582,6 @@ share/doc/uhd/doxygen/html/search/typedefs_c.html
|
||||
share/doc/uhd/doxygen/html/search/typedefs_c.js
|
||||
share/doc/uhd/doxygen/html/search/typedefs_d.html
|
||||
share/doc/uhd/doxygen/html/search/typedefs_d.js
|
||||
share/doc/uhd/doxygen/html/search/typedefs_e.html
|
||||
share/doc/uhd/doxygen/html/search/typedefs_e.js
|
||||
share/doc/uhd/doxygen/html/search/variables_0.html
|
||||
share/doc/uhd/doxygen/html/search/variables_0.js
|
||||
share/doc/uhd/doxygen/html/search/variables_1.html
|
||||
@@ -759,10 +727,6 @@ share/doc/uhd/doxygen/html/structuhd_1_1usrp_1_1mboard__eeprom__t.png
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrp_1_1subdev__spec__pair__t-members.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrp_1_1subdev__spec__pair__t.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrp_1_1subdev__spec__pair__t.png
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrprio__rpc_1_1hshake__args__t-members.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrprio__rpc_1_1hshake__args__t.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrprio__rpc_1_1usrprio__device__info-members.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1usrprio__rpc_1_1usrprio__device__info.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1value__error-members.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1value__error.html
|
||||
share/doc/uhd/doxygen/html/structuhd_1_1value__error.png
|
||||
@@ -799,10 +763,6 @@ share/doc/uhd/doxygen/html/usb__device__handle_8hpp.html
|
||||
share/doc/uhd/doxygen/html/usb__device__handle_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/usb__zero__copy_8hpp.html
|
||||
share/doc/uhd/doxygen/html/usb__zero__copy_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/usrprio__rpc__client_8hpp.html
|
||||
share/doc/uhd/doxygen/html/usrprio__rpc__client_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/usrprio__rpc__common_8hpp.html
|
||||
share/doc/uhd/doxygen/html/usrprio__rpc__common_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/version_8hpp.html
|
||||
share/doc/uhd/doxygen/html/version_8hpp_source.html
|
||||
share/doc/uhd/doxygen/html/vrt__if__packet_8hpp.html
|
||||
|
||||
@@ -1,7 +1,5 @@
|
||||
$NetBSD: distinfo,v 1.4 2015/04/23 18:26:30 joerg Exp $
|
||||
$NetBSD: distinfo,v 1.7 2015/09/06 00:11:12 mef Exp $
|
||||
|
||||
SHA1 (uhd-release_003_007_002.zip) = 41e110454a7e8a7c749226f17dcf49a62c7c4da4
|
||||
RMD160 (uhd-release_003_007_002.zip) = 914115d13028ff753465119848ee9d88811f127b
|
||||
Size (uhd-release_003_007_002.zip) = 90350334 bytes
|
||||
SHA1 (patch-host_include_uhd_transport_nirio_nirio__driver__iface_h) = 2ba6c50f467515bfac9fe330572bb0154154a0ad
|
||||
SHA1 (patch-lib_usrp_b200_b200__io__impl.cpp) = 937003ecd88a31d96c5223c95751ace7622e2256
|
||||
SHA1 (uhd-3.9.0.tar.gz) = 815ef97870a3d0f3d65fa4075a3f2c1c476d1d17
|
||||
RMD160 (uhd-3.9.0.tar.gz) = 69dabc854cb77a2ddde04c4615df602671610ed5
|
||||
Size (uhd-3.9.0.tar.gz) = 2910398 bytes
|
||||
|
||||
@@ -1,4 +1,4 @@
|
||||
# $NetBSD: options.mk,v 1.2 2015/01/31 00:58:06 mef Exp $
|
||||
# $NetBSD: options.mk,v 1.3 2015/08/14 06:19:13 mef Exp $
|
||||
### Set options
|
||||
PKG_OPTIONS_VAR= PKG_OPTIONS.uhd
|
||||
PKG_SUPPORTED_OPTIONS= doxygen manual
|
||||
@@ -13,5 +13,5 @@ PLIST_SRC+= ${PKGDIR}/PLIST.doxygen
|
||||
|
||||
.if !empty(PKG_OPTIONS:Mmanual)
|
||||
BUILD_DEPENDS+= ${PYPKGPREFIX}-docutils-[0-9]*:../../textproc/py-docutils
|
||||
PLIST_SRC+= ${PKGDIR}/PLIST.manual
|
||||
#PLIST_SRC+= ${PKGDIR}/PLIST.manual
|
||||
.endif
|
||||
|
||||
@@ -1,24 +0,0 @@
|
||||
$NetBSD: patch-host_include_uhd_transport_nirio_nirio__driver__iface_h,v 1.1 2014/09/08 07:12:05 mef Exp $
|
||||
|
||||
To avoid asking IOKit/IOKit.h
|
||||
|
||||
--- host/include/uhd/transport/nirio/nirio_driver_iface.h
|
||||
+++ include/uhd/transport/nirio/nirio_driver_iface.h
|
||||
@@ -28,7 +28,7 @@
|
||||
#pragma warning(disable:4201) // nonstandard extension used : nameless struct/union
|
||||
#include <WinIoCtl.h>
|
||||
#pragma warning(default:4201)
|
||||
-#elif !defined(UHD_PLATFORM_LINUX)
|
||||
+#elif !defined(UHD_PLATFORM_LINUX) && !defined(__NetBSD__) && !defined(__FreeBSD__) && !defined(__DragonFly__)
|
||||
#include <IOKit/IOKitLib.h>
|
||||
#endif
|
||||
|
||||
@@ -441,7 +441,7 @@ static inline void init_syncop_out_params(nirio_syncop_out_params_t& param, void
|
||||
|
||||
|
||||
//Device handle definition
|
||||
-#if defined(UHD_PLATFORM_LINUX)
|
||||
+#if defined(UHD_PLATFORM_LINUX) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__DragonFly__)
|
||||
typedef int rio_dev_handle_t;
|
||||
#elif defined(UHD_PLATFORM_WIN32)
|
||||
typedef HANDLE rio_dev_handle_t;
|
||||
@@ -1,22 +0,0 @@
|
||||
$NetBSD: patch-lib_usrp_b200_b200__io__impl.cpp,v 1.1 2015/04/23 18:26:30 joerg Exp $
|
||||
|
||||
--- lib/usrp/b200/b200_io_impl.cpp.orig 2015-04-23 14:23:25.000000000 +0000
|
||||
+++ lib/usrp/b200/b200_io_impl.cpp
|
||||
@@ -184,7 +184,7 @@ boost::optional<uhd::msg_task::msg_type_
|
||||
{
|
||||
managed_recv_buffer::sptr buff = xport->get_recv_buff();
|
||||
if (not buff or buff->size() < 8)
|
||||
- return NULL;
|
||||
+ return boost::none;
|
||||
|
||||
const boost::uint32_t sid = uhd::wtohx(buff->cast<const boost::uint32_t *>()[1]);
|
||||
switch (sid) {
|
||||
@@ -248,7 +248,7 @@ boost::optional<uhd::msg_task::msg_type_
|
||||
default:
|
||||
UHD_MSG(error) << "Got a ctrl packet with unknown SID " << sid << std::endl;
|
||||
}
|
||||
- return NULL;
|
||||
+ return boost::none;
|
||||
}
|
||||
|
||||
/***********************************************************************
|
||||
Reference in New Issue
Block a user